@@ -39,7 +39,11 @@
 #'
 #' average_spectra(biodiesel, c("biodiesel_5_0", "biodiesel_B5", "diesel_unknown"))
 #' @md
-average_spectra <- function(ftir, sample_ids = NA, average_id = "averaged_spectra") {
+average_spectra <- function(
+  ftir,
+  sample_ids = NA,
+  average_id = "averaged_spectra"
+) {
   ftir <- check_ftir_data(ftir)
   intensity_attribute <- attr(ftir, "intensity")
 
@@ -56,7 +60,8 @@ average_spectra <- function(ftir, sample_ids = NA, average_id = "averaged_spectr
 
   if (any(!(sample_ids %in% unique(ftir$sample_id)))) {
     mismatch <- sample_ids[!(sample_ids %in% unique(ftir$sample_id))]
-    cli::cli_abort(c("All provided {.arg sample_ids} must be in {.arg ftir} data.",
+    cli::cli_abort(c(
+      "All provided {.arg sample_ids} must be in {.arg ftir} data.",
       x = "The following {.arg sample_id{?s}} are not present: {.val {mismatch}}."
     ))
   }
@@ -71,52 +76,122 @@ average_spectra <- function(ftir, sample_ids = NA, average_id = "averaged_spectr
   # check wavenumbers matches
   first_wavenumbers <- ftir[ftir$sample_id == sample_ids[1], "wavenumber"]
   other_wavenumbers <- ftir[ftir$sample_id != sample_ids[1], "wavenumber"]
-  if (all(first_wavenumbers %in% other_wavenumbers) && all(other_wavenumbers %in% first_wavenumbers)) {
+  if (
+    all(first_wavenumbers %in% other_wavenumbers) &&
+      all(other_wavenumbers %in% first_wavenumbers)
+  ) {
     # make average - when all wavenumbers are present in all samples
     if (grepl("absorbance", intensity_attribute)) {
-      avg_spectra <- stats::aggregate(absorbance ~ wavenumber, data = ftir, FUN = mean)
+      avg_spectra <- stats::aggregate(
+        absorbance ~ wavenumber,
+        data = ftir,
+        FUN = mean
+      )
     } else {
-      avg_spectra <- stats::aggregate(transmittance ~ wavenumber, data = ftir, FUN = mean)
+      avg_spectra <- stats::aggregate(
+        transmittance ~ wavenumber,
+        data = ftir,
+        FUN = mean
+      )
     }
 
     avg_spectra$sample_id <- average_id
   } else {
     # Mismatch in wavenumbers. Try first to subset data, then if not Can we interpolate & average across the whole range?
-    cli::cli_warn(c("There is a mismatch in the wavenumber axis between sample_ids.",
+    cli::cli_warn(c(
+      "There is a mismatch in the wavenumber axis between sample_ids.",
       i = "Only wavenumber ranges within all samples will be averaged, using linear interpolation."
     ))
 
     # Determine the range over which data should be averaged
-    max_min <- max(sapply(sample_ids, function(x) min(ftir[ftir$sample_id == x, "wavenumber"]), simplify = TRUE, USE.NAMES = FALSE))
-    min_max <- min(sapply(sample_ids, function(x) max(ftir[ftir$sample_id == x, "wavenumber"]), simplify = TRUE, USE.NAMES = FALSE))
+    max_min <- max(sapply(
+      sample_ids,
+      function(x) min(ftir[ftir$sample_id == x, "wavenumber"]),
+      simplify = TRUE,
+      USE.NAMES = FALSE
+    ))
+    min_max <- min(sapply(
+      sample_ids,
+      function(x) max(ftir[ftir$sample_id == x, "wavenumber"]),
+      simplify = TRUE,
+      USE.NAMES = FALSE
+    ))
 
-    first_wavenumbers <- ftir[ftir$sample_id == sample_ids[1] & ftir$wavenumber < min_max & ftir$wavenumber > max_min, "wavenumber"]
-    other_wavenumbers <- ftir[ftir$sample_id != sample_ids[1] & ftir$wavenumber < min_max & ftir$wavenumber > max_min, "wavenumber"]
-    if (length(first_wavenumbers) > 1 && length(other_wavenumbers) > 1 && all(first_wavenumbers %in% other_wavenumbers) && all(other_wavenumbers %in% first_wavenumbers)) {
+    first_wavenumbers <- ftir[
+      ftir$sample_id == sample_ids[1] &
+        ftir$wavenumber < min_max &
+        ftir$wavenumber > max_min,
+      "wavenumber"
+    ]
+    other_wavenumbers <- ftir[
+      ftir$sample_id != sample_ids[1] &
+        ftir$wavenumber < min_max &
+        ftir$wavenumber > max_min,
+      "wavenumber"
+    ]
+    if (
+      length(first_wavenumbers) > 1 &&
+        length(other_wavenumbers) > 1 &&
+        all(first_wavenumbers %in% other_wavenumbers) &&
+        all(other_wavenumbers %in% first_wavenumbers)
+    ) {
       # make average - now wavenumbers are present in all samples for the reduced range
       ftir <- ftir[ftir$wavenumber < min_max & ftir$wavenumber > max_min, ]
       # RECURSION FTW
-      return(average_spectra(ftir = ftir, sample_ids = sample_ids, average_id = average_id))
+      return(average_spectra(
+        ftir = ftir,
+        sample_ids = sample_ids,
+        average_id = average_id
+      ))
     } else {
       # Determine the biggest step size in the data. Most FTIR is resolved to 4 wavenumbers but not all
-      wavenumber_step <- max(sapply(sample_ids, function(x) mean(diff(ftir[ftir$sample_id == x, "wavenumber"])), simplify = TRUE, USE.NAMES = FALSE))
-      interpolated_wavenumbers <- seq(from = max_min, to = min_max, by = wavenumber_step)
-      interp_ftir <- data.frame(wavenumber = numeric(), sample_id = character(), signal = numeric())
-      colnames(interp_ftir)[colnames(interp_ftir) == "signal"] <- colnames(ftir)[!(colnames(ftir) %in% c("wavenumber", "sample_id"))]
+      wavenumber_step <- max(sapply(
+        sample_ids,
+        function(x) mean(diff(ftir[ftir$sample_id == x, "wavenumber"])),
+        simplify = TRUE,
+        USE.NAMES = FALSE
+      ))
+      interpolated_wavenumbers <- seq(
+        from = max_min,
+        to = min_max,
+        by = wavenumber_step
+      )
+      interp_ftir <- data.frame(
+        wavenumber = numeric(),
+        sample_id = character(),
+        signal = numeric()
+      )
+      colnames(interp_ftir)[colnames(interp_ftir) == "signal"] <- colnames(
+        ftir
+      )[!(colnames(ftir) %in% c("wavenumber", "sample_id"))]
 
       for (i in seq_along(sample_ids)) {
-        interp_signal <- stats::approx(ftir[ftir$sample_id == sample_ids[i], ]$wavenumber,
-          ftir[ftir$sample_id == sample_ids[i], colnames(ftir) %in% c("absorbance", "transmittance")],
+        interp_signal <- stats::approx(
+          ftir[ftir$sample_id == sample_ids[i], ]$wavenumber,
+          ftir[
+            ftir$sample_id == sample_ids[i],
+            colnames(ftir) %in% c("absorbance", "transmittance")
+          ],
           xout = interpolated_wavenumbers
         )$y
-        interp_spectra <- data.frame("wavenumber" = interpolated_wavenumbers, "sample_id" = sample_ids[i], "signal" = interp_signal)
-        colnames(interp_spectra)[colnames(interp_spectra) == "signal"] <- colnames(ftir)[!(colnames(ftir) %in% c("wavenumber", "sample_id"))]
+        interp_spectra <- data.frame(
+          "wavenumber" = interpolated_wavenumbers,
+          "sample_id" = sample_ids[i],
+          "signal" = interp_signal
+        )
+        colnames(interp_spectra)[
+          colnames(interp_spectra) == "signal"
+        ] <- colnames(ftir)[!(colnames(ftir) %in% c("wavenumber", "sample_id"))]
 
         interp_ftir <- rbind(interp_ftir, interp_spectra)
       }
 
       # RECURSION AGAIN!
-      return(average_spectra(ftir = interp_ftir, sample_ids = sample_ids, average_id = average_id))
+      return(average_spectra(
+        ftir = interp_ftir,
+        sample_ids = sample_ids,
+        average_id = average_id
+      ))
     }
   }
 
@@ -181,21 +256,29 @@ add_scalar_value <- function(ftir, value, sample_ids = NA) {
 
   if (any(!(sample_ids %in% unique(ftir$sample_id)))) {
     mismatch <- sample_ids[!(sample_ids %in% unique(ftir$sample_id))]
-    cli::cli_abort(c("All provided {.arg sample_ids} must be in {.arg ftir} data.",
+    cli::cli_abort(c(
+      "All provided {.arg sample_ids} must be in {.arg ftir} data.",
       x = "The following {.arg sample_id{?s}} are not present: {.val {mismatch}}."
     ))
   }
 
   if (!is.numeric(value)) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::add_scalar_value}. Provided {.arg value} must be numeric.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::add_scalar_value}. Provided {.arg value} must be numeric.",
       x = "You provided {.obj_type_friendly value}."
     ))
   }
 
   if ("absorbance" %in% colnames(ftir)) {
-    ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[ftir$sample_id %in% sample_ids, ]$absorbance + value
+    ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[
+      ftir$sample_id %in% sample_ids,
+    ]$absorbance +
+      value
   } else {
-    ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[ftir$sample_id %in% sample_ids, ]$transmittance + value
+    ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[
+      ftir$sample_id %in% sample_ids,
+    ]$transmittance +
+      value
   }
 
   return(ftir)
@@ -207,11 +290,16 @@ subtract_scalar_value <- function(ftir, value, sample_ids = NA) {
   ftir <- check_ftir_data(ftir)
 
   if (!is.numeric(value)) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::subtract_scalar_value}. Provided {.arg value} must be numeric.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::subtract_scalar_value}. Provided {.arg value} must be numeric.",
       x = "You provided {.obj_type_friendly value}."
     ))
   }
-  return(add_scalar_value(ftir = ftir, sample_ids = sample_ids, value = value * -1))
+  return(add_scalar_value(
+    ftir = ftir,
+    sample_ids = sample_ids,
+    value = value * -1
+  ))
 }
 
 
@@ -321,7 +409,13 @@ subtract_scalar_value <- function(ftir, value, sample_ids = NA) {
 #' @examples
 #' # Adjust the biodiesel spectra to minimum for each sample
 #' recalculate_baseline(biodiesel, method = "minimum", individually = TRUE)
-recalculate_baseline <- function(ftir, sample_ids = NA, wavenumber_range = NA, method = "average", individually = TRUE) {
+recalculate_baseline <- function(
+  ftir,
+  sample_ids = NA,
+  wavenumber_range = NA,
+  method = "average",
+  individually = TRUE
+) {
   ftir <- check_ftir_data(ftir)
 
   if (length(sample_ids) <= 1) {
@@ -332,40 +426,52 @@ recalculate_baseline <- function(ftir, sample_ids = NA, wavenumber_range = NA, m
 
   if (any(!(sample_ids %in% unique(ftir$sample_id)))) {
     mismatch <- sample_ids[!(sample_ids %in% unique(ftir$sample_id))]
-    cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. All provided {.arg sample_ids} must be in {.arg ftir} data.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::recalculate_baseline}. All provided {.arg sample_ids} must be in {.arg ftir} data.",
       x = "The following {.arg sample_id{?s}} are not present: {.val {mismatch}}."
     ))
   }
 
   if (length(wavenumber_range) < 1 || length(wavenumber_range) > 2) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be of length 1 or 2."))
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be of length 1 or 2."
+    ))
   }
   if (!(all(is.na(wavenumber_range)) || all(is.numeric(wavenumber_range)))) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be {.code numeric} or {.code NA}.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be {.code numeric} or {.code NA}.",
       x = "You provided a {.obj_type_friendly wavenumber_range}."
     ))
   }
 
   if (!is.logical(individually)) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg individually} must be a boolean value.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg individually} must be a boolean value.",
       x = "You provided a {.obj_type_friendly individually}."
     ))
   }
 
   permitted_methods <- c("point", "average", "minimum", "maximum")
   if (length(method) != 1 || !(method %in% permitted_methods)) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg method} must be a string.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg method} must be a string.",
       i = "{.arg method} must be one of {.val {permitted_methods}}."
     ))
   }
 
   if (method == "point" && length(wavenumber_range) == 2) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be one numeric value if {.code method = 'point'}.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be one numeric value if {.code method = 'point'}.",
       i = "The value at the provided wavenumber will be used to baseline adjust data."
     ))
   }
-  if (method %in% c("minimum", "maximum") && all(length(wavenumber_range) == 1, !is.na(wavenumber_range))) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be {.code NA} or two numeric values if {.code method = '{method}'}.",
+  if (
+    method %in%
+      c("minimum", "maximum") &&
+      all(length(wavenumber_range) == 1, !is.na(wavenumber_range))
+  ) {
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be {.code NA} or two numeric values if {.code method = '{method}'}.",
       i = "The minimum (for absorbance spectra) or maximum (for transmittance spectra) value between the provided wavenumbers will be used to baseline adjust data.",
       i = "To adjust by a single point, call the function with {.code method = 'point'}"
     ))
@@ -373,111 +479,257 @@ recalculate_baseline <- function(ftir, sample_ids = NA, wavenumber_range = NA, m
 
   if (method == "point") {
     if (length(wavenumber_range) != 1 || is.na(wavenumber_range)) {
-      cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be a single numeric value.",
+      cli::cli_abort(c(
+        "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be a single numeric value.",
         i = "The value at the provided wavenumber will be used to baseline adjust data."
       ))
     }
     if (individually) {
       for (i in seq_along(sample_ids)) {
         if ("absorbance" %in% colnames(ftir)) {
-          if (wavenumber_range < min(ftir[ftir$sample_id == sample_ids[i], ]$wavenumber) || wavenumber_range > max(ftir[ftir$sample_id == sample_ids[i], ]$wavenumber)) {
-            cli::cli_warn(c("Warning in {.fn PlotFTIR::recalculate_baseline}. Provided wavenumber is not within spectral range.",
+          if (
+            wavenumber_range <
+              min(ftir[ftir$sample_id == sample_ids[i], ]$wavenumber) ||
+              wavenumber_range >
+                max(ftir[ftir$sample_id == sample_ids[i], ]$wavenumber)
+          ) {
+            cli::cli_warn(c(
+              "Warning in {.fn PlotFTIR::recalculate_baseline}. Provided wavenumber is not within spectral range.",
               i = "Using {round(ftir[ftir$sample_id == sample_ids[i],]$wavenumber[which(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i],]$wavenumber) == min(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i],]$wavenumber)))], 0)} cm-1 instead of provided {round(wavenumber_range, 0)} cm-1."
             ))
-          } else if (min(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber)) > 10) {
-            cli::cli_warn(c("Warning in {.fn PlotFTIR::recalculate_baseline}. No wavenumber values in spectra within 10 cm-1 of supplied point.",
+          } else if (
+            min(abs(
+              wavenumber_range -
+                ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+            )) >
+              10
+          ) {
+            cli::cli_warn(c(
+              "Warning in {.fn PlotFTIR::recalculate_baseline}. No wavenumber values in spectra within 10 cm-1 of supplied point.",
               i = "Using {round(ftir[ftir$sample_id == sample_ids[i],]$wavenumber[which(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i],]$wavenumber) == min(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i],]$wavenumber)))], 0)} cm-1 instead of provided {round(wavenumber_range, 0)} cm-1."
             ))
           }
-          adj <- ftir[ftir$sample_id == sample_ids[i], ]$absorbance[which(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber) == min(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber)))]
-          ftir[ftir$sample_id == sample_ids[i], ]$absorbance <- ftir[ftir$sample_id == sample_ids[i], ]$absorbance - adj
+          adj <- ftir[ftir$sample_id == sample_ids[i], ]$absorbance[which(
+            abs(
+              wavenumber_range -
+                ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+            ) ==
+              min(abs(
+                wavenumber_range -
+                  ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+              ))
+          )]
+          ftir[ftir$sample_id == sample_ids[i], ]$absorbance <- ftir[
+            ftir$sample_id == sample_ids[i],
+          ]$absorbance -
+            adj
         } else {
-          adj <- 100 - ftir[ftir$sample_id == sample_ids[i], ]$transmittance[which(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber) == min(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber)))]
-          ftir[ftir$sample_id == sample_ids[i], ]$transmittance <- ftir[ftir$sample_id == sample_ids[i], ]$transmittance + adj
+          adj <- 100 -
+            ftir[ftir$sample_id == sample_ids[i], ]$transmittance[which(
+              abs(
+                wavenumber_range -
+                  ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+              ) ==
+                min(abs(
+                  wavenumber_range -
+                    ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+                ))
+            )]
+          ftir[ftir$sample_id == sample_ids[i], ]$transmittance <- ftir[
+            ftir$sample_id == sample_ids[i],
+          ]$transmittance +
+            adj
         }
       }
     } else {
       adj <- 1e10
       for (i in seq_along(sample_ids)) {
         if ("absorbance" %in% colnames(ftir)) {
-          adj_i <- ftir[ftir$sample_id == sample_ids[i], ]$absorbance[which(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber) == min(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber)))]
+          adj_i <- ftir[ftir$sample_id == sample_ids[i], ]$absorbance[which(
+            abs(
+              wavenumber_range -
+                ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+            ) ==
+              min(abs(
+                wavenumber_range -
+                  ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+              ))
+          )]
         } else {
-          adj_i <- 100 - ftir[ftir$sample_id == sample_ids[i], ]$transmittance[which(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber) == min(abs(wavenumber_range - ftir[ftir$sample_id == sample_ids[i], ]$wavenumber)))]
+          adj_i <- 100 -
+            ftir[ftir$sample_id == sample_ids[i], ]$transmittance[which(
+              abs(
+                wavenumber_range -
+                  ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+              ) ==
+                min(abs(
+                  wavenumber_range -
+                    ftir[ftir$sample_id == sample_ids[i], ]$wavenumber
+                ))
+            )]
         }
         adj <- c(adj, adj_i)[which.min(abs(c(adj, adj_i)))] # returns absolute minimum but keeps the sign
       }
       if ("absorbance" %in% colnames(ftir)) {
-        ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[ftir$sample_id %in% sample_ids, ]$absorbance - adj
+        ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[
+          ftir$sample_id %in% sample_ids,
+        ]$absorbance -
+          adj
       } else {
-        ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[ftir$sample_id %in% sample_ids, ]$transmittance + adj
+        ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[
+          ftir$sample_id %in% sample_ids,
+        ]$transmittance +
+          adj
       }
     }
   } else if (method == "average") {
     if (all(is.na(wavenumber_range))) {
-      cli::cli_warn(c("Adjusting spectra baseline by the average of all values is not analytically useful",
+      cli::cli_warn(c(
+        "Adjusting spectra baseline by the average of all values is not analytically useful",
         i = "Provide a wavenumber range to adjust by the average in that spectral region."
       ))
-      wavenumber_range <- range(ftir[ftir$sample_id %in% sample_ids, ]$wavenumber)
+      wavenumber_range <- range(
+        ftir[ftir$sample_id %in% sample_ids, ]$wavenumber
+      )
     } else if (length(wavenumber_range) != 2) {
-      cli::cli_abort(c("Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be two numeric values.",
+      cli::cli_abort(c(
+        "Error in {.fn PlotFTIR::recalculate_baseline}. {.arg wavenumber_range} must be two numeric values.",
         i = "The average value between the provided wavenumbers will be used to baseline adjust data."
       ))
     }
     if (individually) {
       for (i in seq_along(sample_ids)) {
         if ("absorbance" %in% colnames(ftir)) {
-          adj <- mean(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$absorbance)
-          ftir[ftir$sample_id == sample_ids[i], ]$absorbance <- ftir[ftir$sample_id == sample_ids[i], ]$absorbance - adj
+          adj <- mean(
+            ftir[
+              ftir$sample_id == sample_ids[i] &
+                ftir$wavenumber >= min(wavenumber_range) &
+                ftir$wavenumber <= max(wavenumber_range),
+            ]$absorbance
+          )
+          ftir[ftir$sample_id == sample_ids[i], ]$absorbance <- ftir[
+            ftir$sample_id == sample_ids[i],
+          ]$absorbance -
+            adj
         } else {
-          adj <- 100 - mean(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$transmittance)
-          ftir[ftir$sample_id == sample_ids[i], ]$transmittance <- ftir[ftir$sample_id == sample_ids[i], ]$transmittance + adj
+          adj <- 100 -
+            mean(
+              ftir[
+                ftir$sample_id == sample_ids[i] &
+                  ftir$wavenumber >= min(wavenumber_range) &
+                  ftir$wavenumber <= max(wavenumber_range),
+              ]$transmittance
+            )
+          ftir[ftir$sample_id == sample_ids[i], ]$transmittance <- ftir[
+            ftir$sample_id == sample_ids[i],
+          ]$transmittance +
+            adj
         }
       }
     } else {
       adj <- 1e10
       for (i in seq_along(sample_ids)) {
         if ("absorbance" %in% colnames(ftir)) {
-          adj_i <- mean(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$absorbance)
+          adj_i <- mean(
+            ftir[
+              ftir$sample_id == sample_ids[i] &
+                ftir$wavenumber >= min(wavenumber_range) &
+                ftir$wavenumber <= max(wavenumber_range),
+            ]$absorbance
+          )
         } else {
-          adj_i <- 100 - mean(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$transmittance)
+          adj_i <- 100 -
+            mean(
+              ftir[
+                ftir$sample_id == sample_ids[i] &
+                  ftir$wavenumber >= min(wavenumber_range) &
+                  ftir$wavenumber <= max(wavenumber_range),
+              ]$transmittance
+            )
         }
         adj <- c(adj, adj_i)[which.min(abs(c(adj, adj_i)))] # returns absolute minimum but keeps the sign
       }
       if ("absorbance" %in% colnames(ftir)) {
-        ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[ftir$sample_id %in% sample_ids, ]$absorbance - adj
+        ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[
+          ftir$sample_id %in% sample_ids,
+        ]$absorbance -
+          adj
       } else {
-        ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[ftir$sample_id %in% sample_ids, ]$transmittance + adj
+        ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[
+          ftir$sample_id %in% sample_ids,
+        ]$transmittance +
+          adj
       }
     }
   } else {
     # method is in c("minimum", "maximum")
     if (all(is.na(wavenumber_range))) {
-      wavenumber_range <- range(ftir[ftir$sample_id %in% sample_ids, ]$wavenumber)
+      wavenumber_range <- range(
+        ftir[ftir$sample_id %in% sample_ids, ]$wavenumber
+      )
     }
     if (individually) {
       for (i in seq_along(sample_ids)) {
         if ("absorbance" %in% colnames(ftir)) {
-          adj <- min(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$absorbance)
-          ftir[ftir$sample_id == sample_ids[i], ]$absorbance <- ftir[ftir$sample_id == sample_ids[i], ]$absorbance - adj
+          adj <- min(
+            ftir[
+              ftir$sample_id == sample_ids[i] &
+                ftir$wavenumber >= min(wavenumber_range) &
+                ftir$wavenumber <= max(wavenumber_range),
+            ]$absorbance
+          )
+          ftir[ftir$sample_id == sample_ids[i], ]$absorbance <- ftir[
+            ftir$sample_id == sample_ids[i],
+          ]$absorbance -
+            adj
         } else {
-          adj <- 100 - max(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$transmittance)
-          ftir[ftir$sample_id == sample_ids[i], ]$transmittance <- ftir[ftir$sample_id == sample_ids[i], ]$transmittance + adj
+          adj <- 100 -
+            max(
+              ftir[
+                ftir$sample_id == sample_ids[i] &
+                  ftir$wavenumber >= min(wavenumber_range) &
+                  ftir$wavenumber <= max(wavenumber_range),
+              ]$transmittance
+            )
+          ftir[ftir$sample_id == sample_ids[i], ]$transmittance <- ftir[
+            ftir$sample_id == sample_ids[i],
+          ]$transmittance +
+            adj
         }
       }
     } else {
       adj <- 1e10
       for (i in seq_along(sample_ids)) {
         if ("absorbance" %in% colnames(ftir)) {
-          adj_i <- min(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$absorbance)
+          adj_i <- min(
+            ftir[
+              ftir$sample_id == sample_ids[i] &
+                ftir$wavenumber >= min(wavenumber_range) &
+                ftir$wavenumber <= max(wavenumber_range),
+            ]$absorbance
+          )
         } else {
-          adj_i <- 100 - max(ftir[ftir$sample_id == sample_ids[i] & ftir$wavenumber >= min(wavenumber_range) & ftir$wavenumber <= max(wavenumber_range), ]$transmittance)
+          adj_i <- 100 -
+            max(
+              ftir[
+                ftir$sample_id == sample_ids[i] &
+                  ftir$wavenumber >= min(wavenumber_range) &
+                  ftir$wavenumber <= max(wavenumber_range),
+              ]$transmittance
+            )
         }
         adj <- c(adj, adj_i)[which.min(abs(c(adj, adj_i)))] # returns absolute minimum but keeps the sign
       }
       if ("absorbance" %in% colnames(ftir)) {
-        ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[ftir$sample_id %in% sample_ids, ]$absorbance - adj
+        ftir[ftir$sample_id %in% sample_ids, ]$absorbance <- ftir[
+          ftir$sample_id %in% sample_ids,
+        ]$absorbance -
+          adj
       } else {
-        ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[ftir$sample_id %in% sample_ids, ]$transmittance + adj
+        ftir[ftir$sample_id %in% sample_ids, ]$transmittance <- ftir[
+          ftir$sample_id %in% sample_ids,
+        ]$transmittance +
+          adj
       }
     }
   }
@@ -516,9 +768,14 @@ recalculate_baseline <- function(ftir, sample_ids = NA, wavenumber_range = NA, m
 normalize_spectra <- function(ftir, sample_ids = NA, wavenumber_range = NA) {
   # Check inputs
   ftir <- check_ftir_data(ftir)
-  if ("transmittance" %in% colnames(ftir) || attr(ftir, "intensity") == "transmittance") {
+  if (
+    "transmittance" %in%
+      colnames(ftir) ||
+      attr(ftir, "intensity") == "transmittance"
+  ) {
     # Can't normalize transmission spectra
-    cli::cli_abort(c("Error in {.fn PlotFTIR::normalize_spectra}: Normalization of transmittance spectra not supported.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::normalize_spectra}: Normalization of transmittance spectra not supported.",
       i = "Convert spectra to absorbance using {.fn transmittance_to_absorbance} then try again."
     ))
   }
@@ -531,7 +788,8 @@ normalize_spectra <- function(ftir, sample_ids = NA, wavenumber_range = NA) {
 
   if (any(!(sample_ids %in% unique(ftir$sample_id)))) {
     mismatch <- sample_ids[!(sample_ids %in% unique(ftir$sample_id))]
-    cli::cli_abort(c("Error in {.fn PlotFTIR::normalize_spectra}. All provided {.arg sample_ids} must be in {.arg ftir} data.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::normalize_spectra}. All provided {.arg sample_ids} must be in {.arg ftir} data.",
       x = "The following {.arg sample_id{?s}} are not present: {.val {mismatch}}."
     ))
   }
@@ -541,10 +799,13 @@ normalize_spectra <- function(ftir, sample_ids = NA, wavenumber_range = NA) {
   }
 
   if (length(wavenumber_range) < 2 || length(wavenumber_range) > 2) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::normalize_spectra}. {.arg wavenumber_range} must be of length 2."))
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::normalize_spectra}. {.arg wavenumber_range} must be of length 2."
+    ))
   }
   if (any(is.na(wavenumber_range)) | !all(is.numeric(wavenumber_range))) {
-    cli::cli_abort(c("Error in {.fn PlotFTIR::normalize_spectra}. {.arg wavenumber_range} must be {.code numeric} or {.code NA}.",
+    cli::cli_abort(c(
+      "Error in {.fn PlotFTIR::normalize_spectra}. {.arg wavenumber_range} must be {.code numeric} or {.code NA}.",
       x = "You provided a {.obj_type_friendly wavenumber_range}."
     ))
   }
@@ -552,9 +813,15 @@ normalize_spectra <- function(ftir, sample_ids = NA, wavenumber_range = NA) {
   for (i in seq_along(sample_ids)) {
     sid <- sample_ids[i]
     spectra <- ftir[ftir$sample_id == sid, ]
-    spectra_range <- range(spectra[spectra$wavenumber >= min(wavenumber_range) & spectra$wavenumber <= max(wavenumber_range), ]$absorbance)
+    spectra_range <- range(
+      spectra[
+        spectra$wavenumber >= min(wavenumber_range) &
+          spectra$wavenumber <= max(wavenumber_range),
+      ]$absorbance
+    )
     spectra$absorbance <- spectra$absorbance - spectra_range[1]
-    spectra$absorbance <- spectra$absorbance * (1 / (spectra_range[2] - spectra_range[1]))
+    spectra$absorbance <- spectra$absorbance *
+      (1 / (spectra_range[2] - spectra_range[1]))
     ftir[ftir$sample_id == sid, ]$absorbance <- spectra$absorbance
   }
 
@@ -629,8 +896,14 @@ NULL
 absorbance_to_transmittance <- function(ftir) {
   ftir <- check_ftir_data(ftir)
   normalized <- grepl("normalized", attr(ftir, "intensity"))
-  if (!("absorbance" %in% colnames(ftir)) || attr(ftir, "intensity") %in% c("transmittance", "normalized transmittance")) {
-    cli::cli_abort("Error in {.fn PlotFTIR::absorbance_to_transmittance}. {.arg ftir} must be absorbance data or contain a {.var absorbance} column.")
+  if (
+    !("absorbance" %in% colnames(ftir)) ||
+      attr(ftir, "intensity") %in%
+        c("transmittance", "normalized transmittance")
+  ) {
+    cli::cli_abort(
+      "Error in {.fn PlotFTIR::absorbance_to_transmittance}. {.arg ftir} must be absorbance data or contain a {.var absorbance} column."
+    )
   }
   ftir$transmittance <- (10^(ftir$absorbance * -1)) * 100
   ftir$absorbance <- NULL
@@ -653,8 +926,13 @@ transmittance_to_absorbance <- function(ftir) {
   ftir <- check_ftir_data(ftir)
   normalized <- grepl("normalized", attr(ftir, "intensity"))
 
-  if (!("transmittance" %in% colnames(ftir)) || attr(ftir, "intensity") %in% c("absorbance", "normalized absorbance")) {
-    cli::cli_abort("Error in {.fn PlotFTIR::transmittance_to_absorbance}. {.arg ftir} must be transmittance data or contain a {.var transmittance} column.")
+  if (
+    !("transmittance" %in% colnames(ftir)) ||
+      attr(ftir, "intensity") %in% c("absorbance", "normalized absorbance")
+  ) {
+    cli::cli_abort(
+      "Error in {.fn PlotFTIR::transmittance_to_absorbance}. {.arg ftir} must be transmittance data or contain a {.var transmittance} column."
+    )
   }
 
   ftir$absorbance <- -log(ftir$transmittance / 100, base = 10)
