@@ -307,10 +307,12 @@ test_that("reading .jdx works", {
   )
   # 2D NMR Data
   expect_error(
-    read_ftir(
-      path = system.file("extdata", "isasspc1.dx", package = "readJDX")
-    ),
-    "Could not confirm `infrared` data file."
+    suppressWarnings(
+      read_ftir(
+        path = system.file("extdata", "isasspc1.dx", package = "readJDX")
+      ),
+      "Could not confirm `infrared` data file."
+    )
   )
 })
 
